import base64
from enum import Enum
import json
import logging
import os
import pathlib
import signal
from calendar import timegm
from dataclasses import dataclass
from datetime import datetime, timezone
from typing import Optional
from urllib.parse import urlencode

import click
import jwt
import requests
import uvicorn
from fastapi import FastAPI, Query, Request

from cricket_cookie import env

from cricket_cookie.utils.network import find_free_network_port

logger = logging.getLogger(__name__)


class Keys(Enum):
    USERNAME = "LIGHTNING_USERNAME"
    USER_ID = "LIGHTNING_USER_ID"
    API_KEY = "LIGHTNING_API_KEY"
    JWT_TOKEN = "LIGHTNING_JWT_TOKEN"

    @property
    def suffix(self):
        return self.value.lstrip("LIGHTNING_").lower()


@dataclass
class JWTToken:
    @classmethod
    def is_expired(cls, token) -> bool:
        try:
            claim = jwt.decode(token, options={"verify_signature": False})
            now = timegm(datetime.now(tz=timezone.utc).utctimetuple())
            # if token is about to expire, refresh
            expired = claim["exp"] < now - env.LEEWAY
            if expired:
                logger.debug("token is expired")
            return expired
        except BaseException:
            return True


@dataclass
class Auth:
    username: Optional[str] = None
    user_id: Optional[str] = None
    api_key: Optional[str] = None
    jwt_token: Optional[str] = None

    secrets_file = pathlib.Path(env.LIGHTNING_CREDENTIAL_PATH)

    def __post_init__(self):
        for key in Keys:
            setattr(self, key.suffix, os.environ.get(key.value, None))

        self._with_env_var = bool(
            self.jwt_token
            or self.user_id and self.api_key)  # used by authenticate method
        if self.api_key and not self.user_id:
            raise ValueError(
                f"{Keys.USER_ID.value} is missing from env variables. "
                "To use env vars for authentication "
                f"both {Keys.USER_ID.value} and {Keys.API_KEY.value} should be set."
            )

    def load(self) -> bool:
        """Load credentials from disk and update properties with credentials.

        Returns
        ----------
        True if credentials are available.
        """
        if not self.secrets_file.exists():
            logger.debug("Credentials file not found.")
            return False
        with self.secrets_file.open() as creds:
            credentials = json.load(creds)
            for key in Keys:
                setattr(self, key.suffix, credentials.get(key.suffix, None))
            return True

    def save(self,
             token: str,
             username: str = "",
             user_id: str = "",
             api_key="") -> None:
        """save credentials to disk."""
        self.secrets_file.parent.mkdir(exist_ok=True, parents=True)
        with open(self.secrets_file, "w") as f:
            json.dump(
                dict(token=token,
                     username=username,
                     user_id=user_id,
                     api_key=api_key),
                f,
            )

        self.username = username
        self.jwt_token = token
        self.user_id = user_id
        self.api_key = api_key
        logger.debug("credentials saved successfully")

    @classmethod
    def clear(cls) -> None:
        """remove credentials from disk and env variables."""
        if cls.secrets_file.exists():
            cls.secrets_file.unlink()
        for key in Keys:
            os.environ.pop(key.value, None)
        logger.debug("credentials removed successfully")

    @property
    def auth_header(self) -> Optional[str]:
        """authentication header used by lightning-cloud client."""
        if self.jwt_token:
            return f"Bearer {self.jwt_token}"
        if self.api_key:
            token = f"{self.user_id}:{self.api_key}"
            return f"Basic {base64.b64encode(token.encode('ascii')).decode('ascii')}"  # noqa E501
        raise AttributeError(
            "Authentication Failed, no authentication header available. "
            "This is most likely a bug in the LightningCloud Framework")

    def _run_server(self) -> None:
        """start a server to complete authentication."""
        AuthServer().login_with_browser(self)

    def authenticate(self) -> Optional[str]:
        """Performs end to end authentication flow.

        Returns
        ----------
        authorization header to use when authentication completes.
        """
        if self._with_env_var:
            logger.debug("successfully loaded credentials from env")
            return self.auth_header

        if not self.load():
            logger.debug(
                "failed to load credentials, opening browser to get new.")
            self._run_server()

        elif JWTToken.is_expired(self.jwt_token):
            logger.debug("token has expired, opening browser to get new.")
            self._run_server()
        return self.auth_header


class AuthServer:
    def get_auth_url(self, port: int) -> str:
        redirect_uri = f"http://localhost:{port}/login-complete"
        params = urlencode(dict(redirectTo=redirect_uri))
        return f"{env.LIGHTNING_CLOUD_URL}/sign-in?{params}"

    def login_with_browser(self, auth: Auth) -> None:
        app = FastAPI()
        port = find_free_network_port()
        url = self.get_auth_url(port)
        try:
            # check if server is reachable or catch any network errors
            requests.head(url, verify=not env.IS_DEV_ENV)
        except requests.ConnectionError as e:
            raise requests.ConnectionError(
                f"No internet connection available. Please connect to a stable internet connection \n{e}"  # noqa E501
            )
        except requests.RequestException as e:
            raise requests.RequestException(
                f"An error occurred with the request. Please report this issue to Lightning Team \n{e}"  # noqa E501
            )

        logger.info(f"login started for lightning.ai, opening {url}")
        click.launch(url)

        @app.get("/login-complete")
        async def save_token(request: Request,
                             token="",
                             key="",
                             user_id: str = Query("", alias="userID")):
            if token:
                auth.save(token,
                          username=user_id,
                          user_id=user_id,
                          api_key=key)
                from cricket_cookie.rest_client import GridRestClient

                user = GridRestClient().auth_service_get_user()
                logger.info("Authentication Successful")
                logger.info(
                    f"You are logged in as {user.first_name or user.username}")
                response = "login complete you can close the tab now"
            else:
                logger.warning(
                    "Authentication Failed. This is most likely because you're using an older version of the cli. \n"  # noqa E501
                    "Please try to update the cli or open an issue with this information \n"  # noqa E501
                    f"expected token in {request.query_params.items()}")
                response = "login failed, look at terminal/cmd for more info"
            # redirect them to lightning.ai with auth credentials
            # or getting started guide.
            os.kill(os.getpid(), signal.SIGTERM)
            return response

        server = uvicorn.Server(
            config=uvicorn.Config(app, port=port, log_level="error"))
        server.run()



# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from cricket_cookie.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class AuthServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def auth_service_get_user(self,
                              **kwargs) -> 'V1GetUserResponse':  # noqa: E501
        """auth_service_get_user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_service_get_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1GetUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.auth_service_get_user_with_http_info(
                **kwargs)  # noqa: E501
        else:
            (data) = self.auth_service_get_user_with_http_info(
                **kwargs)  # noqa: E501
            return data

    def auth_service_get_user_with_http_info(
            self, **kwargs) -> 'V1GetUserResponse':  # noqa: E501
        """auth_service_get_user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_service_get_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1GetUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'"
                                " to method auth_service_get_user" % key)
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            'Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
                ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/auth/user',
            'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetUserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def auth_service_login(self, body: 'V1LoginRequest',
                           **kwargs) -> 'V1LoginResponse':  # noqa: E501
        """auth_service_login  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_service_login(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1LoginRequest body: (required)
        :return: V1LoginResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.auth_service_login_with_http_info(
                body, **kwargs)  # noqa: E501
        else:
            (data) = self.auth_service_login_with_http_info(
                body, **kwargs)  # noqa: E501
            return data

    def auth_service_login_with_http_info(
            self, body: 'V1LoginRequest',
            **kwargs) -> 'V1LoginResponse':  # noqa: E501
        """auth_service_login  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_service_login_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1LoginRequest body: (required)
        :return: V1LoginResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'"
                                " to method auth_service_login" % key)
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and (
                'body' not in params or params['body'] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `body` when calling `auth_service_login`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            'Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
                ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/auth/login',
            'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1LoginResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def auth_service_logout(self, body: 'V1LogoutRequest',
                            **kwargs) -> 'V1LogoutResponse':  # noqa: E501
        """auth_service_logout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_service_logout(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1LogoutRequest body: (required)
        :return: V1LogoutResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.auth_service_logout_with_http_info(
                body, **kwargs)  # noqa: E501
        else:
            (data) = self.auth_service_logout_with_http_info(
                body, **kwargs)  # noqa: E501
            return data

    def auth_service_logout_with_http_info(
            self, body: 'V1LogoutRequest',
            **kwargs) -> 'V1LogoutResponse':  # noqa: E501
        """auth_service_logout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_service_logout_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1LogoutRequest body: (required)
        :return: V1LogoutResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'"
                                " to method auth_service_logout" % key)
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and (
                'body' not in params or params['body'] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `body` when calling `auth_service_logout`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            'Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
                ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/auth/logout',
            'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1LogoutResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def auth_service_refresh(self, body: 'V1RefreshRequest',
                             **kwargs) -> 'V1RefreshResponse':  # noqa: E501
        """auth_service_refresh  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_service_refresh(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1RefreshRequest body: (required)
        :return: V1RefreshResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.auth_service_refresh_with_http_info(
                body, **kwargs)  # noqa: E501
        else:
            (data) = self.auth_service_refresh_with_http_info(
                body, **kwargs)  # noqa: E501
            return data

    def auth_service_refresh_with_http_info(
            self, body: 'V1RefreshRequest',
            **kwargs) -> 'V1RefreshResponse':  # noqa: E501
        """auth_service_refresh  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.auth_service_refresh_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1RefreshRequest body: (required)
        :return: V1RefreshResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'"
                                " to method auth_service_refresh" % key)
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and (
                'body' not in params or params['body'] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `body` when calling `auth_service_refresh`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            'Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
                ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/auth/refresh',
            'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1RefreshResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from cricket_cookie.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class V1CreateLightningappRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'local_source': 'bool',
        'name': 'str',
        'spec': 'V1LightningappSpec'
    }

    attribute_map = {
        'description': 'description',
        'local_source': 'localSource',
        'name': 'name',
        'spec': 'spec'
    }

    def __init__(self,
                 description: 'str' = None,
                 local_source: 'bool' = None,
                 name: 'str' = None,
                 spec: 'V1LightningappSpec' = None,
                 _configuration=None):  # noqa: E501
        """V1CreateLightningappRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._description = None
        self._local_source = None
        self._name = None
        self._spec = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if local_source is not None:
            self.local_source = local_source
        if name is not None:
            self.name = name
        if spec is not None:
            self.spec = spec

    @property
    def description(self) -> 'str':
        """Gets the description of this V1CreateLightningappRequest.  # noqa: E501


        :return: The description of this V1CreateLightningappRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this V1CreateLightningappRequest.


        :param description: The description of this V1CreateLightningappRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def local_source(self) -> 'bool':
        """Gets the local_source of this V1CreateLightningappRequest.  # noqa: E501

        Indicates that the client wishes to upload the directory that has the source code. In this case, app's status is populated with the presigned URL and the app's spec is set by the server to the S3 tarball that holds the sourcecode.  # noqa: E501

        :return: The local_source of this V1CreateLightningappRequest.  # noqa: E501
        :rtype: bool
        """
        return self._local_source

    @local_source.setter
    def local_source(self, local_source: 'bool'):
        """Sets the local_source of this V1CreateLightningappRequest.

        Indicates that the client wishes to upload the directory that has the source code. In this case, app's status is populated with the presigned URL and the app's spec is set by the server to the S3 tarball that holds the sourcecode.  # noqa: E501

        :param local_source: The local_source of this V1CreateLightningappRequest.  # noqa: E501
        :type: bool
        """

        self._local_source = local_source

    @property
    def name(self) -> 'str':
        """Gets the name of this V1CreateLightningappRequest.  # noqa: E501


        :return: The name of this V1CreateLightningappRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1CreateLightningappRequest.


        :param name: The name of this V1CreateLightningappRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def spec(self) -> 'V1LightningappSpec':
        """Gets the spec of this V1CreateLightningappRequest.  # noqa: E501


        :return: The spec of this V1CreateLightningappRequest.  # noqa: E501
        :rtype: V1LightningappSpec
        """
        return self._spec

    @spec.setter
    def spec(self, spec: 'V1LightningappSpec'):
        """Sets the spec of this V1CreateLightningappRequest.


        :param spec: The spec of this V1CreateLightningappRequest.  # noqa: E501
        :type: V1LightningappSpec
        """

        self._spec = spec

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict()
                        if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()))
            else:
                result[attr] = value
        if issubclass(V1CreateLightningappRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1CreateLightningappRequest') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1CreateLightningappRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1CreateLightningappRequest') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1CreateLightningappRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from cricket_cookie.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class V1Membership(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active_experiments_count': 'str',
        'active_sessions_count': 'str',
        'balance': 'float',
        'created_at': 'datetime',
        'datastore_count': 'str',
        'description': 'str',
        'membership_count': 'str',
        'name': 'str',
        'project_id': 'str',
        'roles': 'list[V1Role]',
        'updated_at': 'datetime',
        'user_id': 'str'
    }

    attribute_map = {
        'active_experiments_count': 'activeExperimentsCount',
        'active_sessions_count': 'activeSessionsCount',
        'balance': 'balance',
        'created_at': 'createdAt',
        'datastore_count': 'datastoreCount',
        'description': 'description',
        'membership_count': 'membershipCount',
        'name': 'name',
        'project_id': 'projectId',
        'roles': 'roles',
        'updated_at': 'updatedAt',
        'user_id': 'userId'
    }

    def __init__(self,
                 active_experiments_count: 'str' = None,
                 active_sessions_count: 'str' = None,
                 balance: 'float' = None,
                 created_at: 'datetime' = None,
                 datastore_count: 'str' = None,
                 description: 'str' = None,
                 membership_count: 'str' = None,
                 name: 'str' = None,
                 project_id: 'str' = None,
                 roles: 'list[V1Role]' = None,
                 updated_at: 'datetime' = None,
                 user_id: 'str' = None,
                 _configuration=None):  # noqa: E501
        """V1Membership - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._active_experiments_count = None
        self._active_sessions_count = None
        self._balance = None
        self._created_at = None
        self._datastore_count = None
        self._description = None
        self._membership_count = None
        self._name = None
        self._project_id = None
        self._roles = None
        self._updated_at = None
        self._user_id = None
        self.discriminator = None

        if active_experiments_count is not None:
            self.active_experiments_count = active_experiments_count
        if active_sessions_count is not None:
            self.active_sessions_count = active_sessions_count
        if balance is not None:
            self.balance = balance
        if created_at is not None:
            self.created_at = created_at
        if datastore_count is not None:
            self.datastore_count = datastore_count
        if description is not None:
            self.description = description
        if membership_count is not None:
            self.membership_count = membership_count
        if name is not None:
            self.name = name
        if project_id is not None:
            self.project_id = project_id
        if roles is not None:
            self.roles = roles
        if updated_at is not None:
            self.updated_at = updated_at
        if user_id is not None:
            self.user_id = user_id

    @property
    def active_experiments_count(self) -> 'str':
        """Gets the active_experiments_count of this V1Membership.  # noqa: E501


        :return: The active_experiments_count of this V1Membership.  # noqa: E501
        :rtype: str
        """
        return self._active_experiments_count

    @active_experiments_count.setter
    def active_experiments_count(self, active_experiments_count: 'str'):
        """Sets the active_experiments_count of this V1Membership.


        :param active_experiments_count: The active_experiments_count of this V1Membership.  # noqa: E501
        :type: str
        """

        self._active_experiments_count = active_experiments_count

    @property
    def active_sessions_count(self) -> 'str':
        """Gets the active_sessions_count of this V1Membership.  # noqa: E501


        :return: The active_sessions_count of this V1Membership.  # noqa: E501
        :rtype: str
        """
        return self._active_sessions_count

    @active_sessions_count.setter
    def active_sessions_count(self, active_sessions_count: 'str'):
        """Sets the active_sessions_count of this V1Membership.


        :param active_sessions_count: The active_sessions_count of this V1Membership.  # noqa: E501
        :type: str
        """

        self._active_sessions_count = active_sessions_count

    @property
    def balance(self) -> 'float':
        """Gets the balance of this V1Membership.  # noqa: E501


        :return: The balance of this V1Membership.  # noqa: E501
        :rtype: float
        """
        return self._balance

    @balance.setter
    def balance(self, balance: 'float'):
        """Sets the balance of this V1Membership.


        :param balance: The balance of this V1Membership.  # noqa: E501
        :type: float
        """

        self._balance = balance

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1Membership.  # noqa: E501


        :return: The created_at of this V1Membership.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1Membership.


        :param created_at: The created_at of this V1Membership.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def datastore_count(self) -> 'str':
        """Gets the datastore_count of this V1Membership.  # noqa: E501


        :return: The datastore_count of this V1Membership.  # noqa: E501
        :rtype: str
        """
        return self._datastore_count

    @datastore_count.setter
    def datastore_count(self, datastore_count: 'str'):
        """Sets the datastore_count of this V1Membership.


        :param datastore_count: The datastore_count of this V1Membership.  # noqa: E501
        :type: str
        """

        self._datastore_count = datastore_count

    @property
    def description(self) -> 'str':
        """Gets the description of this V1Membership.  # noqa: E501


        :return: The description of this V1Membership.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this V1Membership.


        :param description: The description of this V1Membership.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def membership_count(self) -> 'str':
        """Gets the membership_count of this V1Membership.  # noqa: E501


        :return: The membership_count of this V1Membership.  # noqa: E501
        :rtype: str
        """
        return self._membership_count

    @membership_count.setter
    def membership_count(self, membership_count: 'str'):
        """Sets the membership_count of this V1Membership.


        :param membership_count: The membership_count of this V1Membership.  # noqa: E501
        :type: str
        """

        self._membership_count = membership_count

    @property
    def name(self) -> 'str':
        """Gets the name of this V1Membership.  # noqa: E501


        :return: The name of this V1Membership.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1Membership.


        :param name: The name of this V1Membership.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1Membership.  # noqa: E501


        :return: The project_id of this V1Membership.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1Membership.


        :param project_id: The project_id of this V1Membership.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def roles(self) -> 'list[V1Role]':
        """Gets the roles of this V1Membership.  # noqa: E501


        :return: The roles of this V1Membership.  # noqa: E501
        :rtype: list[V1Role]
        """
        return self._roles

    @roles.setter
    def roles(self, roles: 'list[V1Role]'):
        """Sets the roles of this V1Membership.


        :param roles: The roles of this V1Membership.  # noqa: E501
        :type: list[V1Role]
        """

        self._roles = roles

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1Membership.  # noqa: E501


        :return: The updated_at of this V1Membership.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1Membership.


        :param updated_at: The updated_at of this V1Membership.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1Membership.  # noqa: E501


        :return: The user_id of this V1Membership.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1Membership.


        :param user_id: The user_id of this V1Membership.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict()
                        if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()))
            else:
                result[attr] = value
        if issubclass(V1Membership, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1Membership') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Membership):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1Membership') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Membership):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from cricket_cookie.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class V1ComputeConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'env_vars': 'list[str]',
        'instance_type': 'str',
        'max_replicas': 'int',
        'min_replicas': 'int',
        'resources': 'V1Resources'
    }

    attribute_map = {
        'env_vars': 'envVars',
        'instance_type': 'instanceType',
        'max_replicas': 'maxReplicas',
        'min_replicas': 'minReplicas',
        'resources': 'resources'
    }

    def __init__(self,
                 env_vars: 'list[str]' = None,
                 instance_type: 'str' = None,
                 max_replicas: 'int' = None,
                 min_replicas: 'int' = None,
                 resources: 'V1Resources' = None,
                 _configuration=None):  # noqa: E501
        """V1ComputeConfig - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._env_vars = None
        self._instance_type = None
        self._max_replicas = None
        self._min_replicas = None
        self._resources = None
        self.discriminator = None

        if env_vars is not None:
            self.env_vars = env_vars
        if instance_type is not None:
            self.instance_type = instance_type
        if max_replicas is not None:
            self.max_replicas = max_replicas
        if min_replicas is not None:
            self.min_replicas = min_replicas
        if resources is not None:
            self.resources = resources

    @property
    def env_vars(self) -> 'list[str]':
        """Gets the env_vars of this V1ComputeConfig.  # noqa: E501


        :return: The env_vars of this V1ComputeConfig.  # noqa: E501
        :rtype: list[str]
        """
        return self._env_vars

    @env_vars.setter
    def env_vars(self, env_vars: 'list[str]'):
        """Sets the env_vars of this V1ComputeConfig.


        :param env_vars: The env_vars of this V1ComputeConfig.  # noqa: E501
        :type: list[str]
        """

        self._env_vars = env_vars

    @property
    def instance_type(self) -> 'str':
        """Gets the instance_type of this V1ComputeConfig.  # noqa: E501


        :return: The instance_type of this V1ComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type: 'str'):
        """Sets the instance_type of this V1ComputeConfig.


        :param instance_type: The instance_type of this V1ComputeConfig.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def max_replicas(self) -> 'int':
        """Gets the max_replicas of this V1ComputeConfig.  # noqa: E501


        :return: The max_replicas of this V1ComputeConfig.  # noqa: E501
        :rtype: int
        """
        return self._max_replicas

    @max_replicas.setter
    def max_replicas(self, max_replicas: 'int'):
        """Sets the max_replicas of this V1ComputeConfig.


        :param max_replicas: The max_replicas of this V1ComputeConfig.  # noqa: E501
        :type: int
        """

        self._max_replicas = max_replicas

    @property
    def min_replicas(self) -> 'int':
        """Gets the min_replicas of this V1ComputeConfig.  # noqa: E501


        :return: The min_replicas of this V1ComputeConfig.  # noqa: E501
        :rtype: int
        """
        return self._min_replicas

    @min_replicas.setter
    def min_replicas(self, min_replicas: 'int'):
        """Sets the min_replicas of this V1ComputeConfig.


        :param min_replicas: The min_replicas of this V1ComputeConfig.  # noqa: E501
        :type: int
        """

        self._min_replicas = min_replicas

    @property
    def resources(self) -> 'V1Resources':
        """Gets the resources of this V1ComputeConfig.  # noqa: E501


        :return: The resources of this V1ComputeConfig.  # noqa: E501
        :rtype: V1Resources
        """
        return self._resources

    @resources.setter
    def resources(self, resources: 'V1Resources'):
        """Sets the resources of this V1ComputeConfig.


        :param resources: The resources of this V1ComputeConfig.  # noqa: E501
        :type: V1Resources
        """

        self._resources = resources

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict()
                        if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()))
            else:
                result[attr] = value
        if issubclass(V1ComputeConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ComputeConfig') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ComputeConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1ComputeConfig') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1ComputeConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from cricket_cookie.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class V1Resources(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu': 'str',
        'extra': 'dict(str, str)',
        'gpu': 'str',
        'storage_gb': 'str'
    }

    attribute_map = {
        'cpu': 'cpu',
        'extra': 'extra',
        'gpu': 'gpu',
        'storage_gb': 'storageGb'
    }

    def __init__(self,
                 cpu: 'str' = None,
                 extra: 'dict(str, str)' = None,
                 gpu: 'str' = None,
                 storage_gb: 'str' = None,
                 _configuration=None):  # noqa: E501
        """V1Resources - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu = None
        self._extra = None
        self._gpu = None
        self._storage_gb = None
        self.discriminator = None

        if cpu is not None:
            self.cpu = cpu
        if extra is not None:
            self.extra = extra
        if gpu is not None:
            self.gpu = gpu
        if storage_gb is not None:
            self.storage_gb = storage_gb

    @property
    def cpu(self) -> 'str':
        """Gets the cpu of this V1Resources.  # noqa: E501


        :return: The cpu of this V1Resources.  # noqa: E501
        :rtype: str
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu: 'str'):
        """Sets the cpu of this V1Resources.


        :param cpu: The cpu of this V1Resources.  # noqa: E501
        :type: str
        """

        self._cpu = cpu

    @property
    def extra(self) -> 'dict(str, str)':
        """Gets the extra of this V1Resources.  # noqa: E501


        :return: The extra of this V1Resources.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._extra

    @extra.setter
    def extra(self, extra: 'dict(str, str)'):
        """Sets the extra of this V1Resources.


        :param extra: The extra of this V1Resources.  # noqa: E501
        :type: dict(str, str)
        """

        self._extra = extra

    @property
    def gpu(self) -> 'str':
        """Gets the gpu of this V1Resources.  # noqa: E501


        :return: The gpu of this V1Resources.  # noqa: E501
        :rtype: str
        """
        return self._gpu

    @gpu.setter
    def gpu(self, gpu: 'str'):
        """Sets the gpu of this V1Resources.


        :param gpu: The gpu of this V1Resources.  # noqa: E501
        :type: str
        """

        self._gpu = gpu

    @property
    def storage_gb(self) -> 'str':
        """Gets the storage_gb of this V1Resources.  # noqa: E501


        :return: The storage_gb of this V1Resources.  # noqa: E501
        :rtype: str
        """
        return self._storage_gb

    @storage_gb.setter
    def storage_gb(self, storage_gb: 'str'):
        """Sets the storage_gb of this V1Resources.


        :param storage_gb: The storage_gb of this V1Resources.  # noqa: E501
        :type: str
        """

        self._storage_gb = storage_gb

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict()
                        if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()))
            else:
                result[attr] = value
        if issubclass(V1Resources, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1Resources') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Resources):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1Resources') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Resources):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from cricket_cookie.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class V1LightningappStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'image_id': 'str',
        'last_state_status_transition_timestamp': 'datetime',
        'message': 'str',
        'phase': 'V1LightningappState',
        'source_upload_url': 'str',
        'start_timestamp': 'datetime',
        'stop_timestamp': 'datetime',
        'url': 'str'
    }

    attribute_map = {
        'image_id': 'imageId',
        'last_state_status_transition_timestamp':
        'lastStateStatusTransitionTimestamp',
        'message': 'message',
        'phase': 'phase',
        'source_upload_url': 'sourceUploadUrl',
        'start_timestamp': 'startTimestamp',
        'stop_timestamp': 'stopTimestamp',
        'url': 'url'
    }

    def __init__(self,
                 image_id: 'str' = None,
                 last_state_status_transition_timestamp: 'datetime' = None,
                 message: 'str' = None,
                 phase: 'V1LightningappState' = None,
                 source_upload_url: 'str' = None,
                 start_timestamp: 'datetime' = None,
                 stop_timestamp: 'datetime' = None,
                 url: 'str' = None,
                 _configuration=None):  # noqa: E501
        """V1LightningappStatus - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._image_id = None
        self._last_state_status_transition_timestamp = None
        self._message = None
        self._phase = None
        self._source_upload_url = None
        self._start_timestamp = None
        self._stop_timestamp = None
        self._url = None
        self.discriminator = None

        if image_id is not None:
            self.image_id = image_id
        if last_state_status_transition_timestamp is not None:
            self.last_state_status_transition_timestamp = last_state_status_transition_timestamp
        if message is not None:
            self.message = message
        if phase is not None:
            self.phase = phase
        if source_upload_url is not None:
            self.source_upload_url = source_upload_url
        if start_timestamp is not None:
            self.start_timestamp = start_timestamp
        if stop_timestamp is not None:
            self.stop_timestamp = stop_timestamp
        if url is not None:
            self.url = url

    @property
    def image_id(self) -> 'str':
        """Gets the image_id of this V1LightningappStatus.  # noqa: E501


        :return: The image_id of this V1LightningappStatus.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id: 'str'):
        """Sets the image_id of this V1LightningappStatus.


        :param image_id: The image_id of this V1LightningappStatus.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def last_state_status_transition_timestamp(self) -> 'datetime':
        """Gets the last_state_status_transition_timestamp of this V1LightningappStatus.  # noqa: E501


        :return: The last_state_status_transition_timestamp of this V1LightningappStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_state_status_transition_timestamp

    @last_state_status_transition_timestamp.setter
    def last_state_status_transition_timestamp(
            self, last_state_status_transition_timestamp: 'datetime'):
        """Sets the last_state_status_transition_timestamp of this V1LightningappStatus.


        :param last_state_status_transition_timestamp: The last_state_status_transition_timestamp of this V1LightningappStatus.  # noqa: E501
        :type: datetime
        """

        self._last_state_status_transition_timestamp = last_state_status_transition_timestamp

    @property
    def message(self) -> 'str':
        """Gets the message of this V1LightningappStatus.  # noqa: E501


        :return: The message of this V1LightningappStatus.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message: 'str'):
        """Sets the message of this V1LightningappStatus.


        :param message: The message of this V1LightningappStatus.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def phase(self) -> 'V1LightningappState':
        """Gets the phase of this V1LightningappStatus.  # noqa: E501


        :return: The phase of this V1LightningappStatus.  # noqa: E501
        :rtype: V1LightningappState
        """
        return self._phase

    @phase.setter
    def phase(self, phase: 'V1LightningappState'):
        """Sets the phase of this V1LightningappStatus.


        :param phase: The phase of this V1LightningappStatus.  # noqa: E501
        :type: V1LightningappState
        """

        self._phase = phase

    @property
    def source_upload_url(self) -> 'str':
        """Gets the source_upload_url of this V1LightningappStatus.  # noqa: E501

        url to which the source code can be uploaded - needed only if local source and not github. Client will send the request that indicates that it needs to upload the source to s3, controlplane will fill this url and response will be sent back to the client. Client will then use this url to upload the source to s3.  # noqa: E501

        :return: The source_upload_url of this V1LightningappStatus.  # noqa: E501
        :rtype: str
        """
        return self._source_upload_url

    @source_upload_url.setter
    def source_upload_url(self, source_upload_url: 'str'):
        """Sets the source_upload_url of this V1LightningappStatus.

        url to which the source code can be uploaded - needed only if local source and not github. Client will send the request that indicates that it needs to upload the source to s3, controlplane will fill this url and response will be sent back to the client. Client will then use this url to upload the source to s3.  # noqa: E501

        :param source_upload_url: The source_upload_url of this V1LightningappStatus.  # noqa: E501
        :type: str
        """

        self._source_upload_url = source_upload_url

    @property
    def start_timestamp(self) -> 'datetime':
        """Gets the start_timestamp of this V1LightningappStatus.  # noqa: E501


        :return: The start_timestamp of this V1LightningappStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._start_timestamp

    @start_timestamp.setter
    def start_timestamp(self, start_timestamp: 'datetime'):
        """Sets the start_timestamp of this V1LightningappStatus.


        :param start_timestamp: The start_timestamp of this V1LightningappStatus.  # noqa: E501
        :type: datetime
        """

        self._start_timestamp = start_timestamp

    @property
    def stop_timestamp(self) -> 'datetime':
        """Gets the stop_timestamp of this V1LightningappStatus.  # noqa: E501


        :return: The stop_timestamp of this V1LightningappStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._stop_timestamp

    @stop_timestamp.setter
    def stop_timestamp(self, stop_timestamp: 'datetime'):
        """Sets the stop_timestamp of this V1LightningappStatus.


        :param stop_timestamp: The stop_timestamp of this V1LightningappStatus.  # noqa: E501
        :type: datetime
        """

        self._stop_timestamp = stop_timestamp

    @property
    def url(self) -> 'str':
        """Gets the url of this V1LightningappStatus.  # noqa: E501


        :return: The url of this V1LightningappStatus.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url: 'str'):
        """Sets the url of this V1LightningappStatus.


        :param url: The url of this V1LightningappStatus.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict()
                        if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()))
            else:
                result[attr] = value
        if issubclass(V1LightningappStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1LightningappStatus') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LightningappStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1LightningappStatus') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1LightningappStatus):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from cricket_cookie.openapi.api.auth_service_api import AuthServiceApi
from cricket_cookie.openapi.api.cluster_service_api import ClusterServiceApi
from cricket_cookie.openapi.api.lightningapp_service_api import LightningappServiceApi
from cricket_cookie.openapi.api.projects_service_api import ProjectsServiceApi
from cricket_cookie.openapi.api.user_service_api import UserServiceApi



# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from cricket_cookie.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class V1LightningappSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_entrypoint_file': 'str',
        'cluster_id': 'str',
        'desired_state': 'V1LightningappState',
        'enable_app_server': 'bool',
        'flow_servers': 'list[V1Flowserver]',
        'image_spec': 'Gridv1ImageSpec',
        'pause_automation': 'bool',
        'source_code_url': 'str',
        'user_id': 'str',
        'works': 'list[V1Work]'
    }

    attribute_map = {
        'app_entrypoint_file': 'appEntrypointFile',
        'cluster_id': 'clusterId',
        'desired_state': 'desiredState',
        'enable_app_server': 'enableAppServer',
        'flow_servers': 'flowServers',
        'image_spec': 'imageSpec',
        'pause_automation': 'pauseAutomation',
        'source_code_url': 'sourceCodeUrl',
        'user_id': 'userId',
        'works': 'works'
    }

    def __init__(self,
                 app_entrypoint_file: 'str' = None,
                 cluster_id: 'str' = None,
                 desired_state: 'V1LightningappState' = None,
                 enable_app_server: 'bool' = None,
                 flow_servers: 'list[V1Flowserver]' = None,
                 image_spec: 'Gridv1ImageSpec' = None,
                 pause_automation: 'bool' = None,
                 source_code_url: 'str' = None,
                 user_id: 'str' = None,
                 works: 'list[V1Work]' = None,
                 _configuration=None):  # noqa: E501
        """V1LightningappSpec - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._app_entrypoint_file = None
        self._cluster_id = None
        self._desired_state = None
        self._enable_app_server = None
        self._flow_servers = None
        self._image_spec = None
        self._pause_automation = None
        self._source_code_url = None
        self._user_id = None
        self._works = None
        self.discriminator = None

        if app_entrypoint_file is not None:
            self.app_entrypoint_file = app_entrypoint_file
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if desired_state is not None:
            self.desired_state = desired_state
        if enable_app_server is not None:
            self.enable_app_server = enable_app_server
        if flow_servers is not None:
            self.flow_servers = flow_servers
        if image_spec is not None:
            self.image_spec = image_spec
        if pause_automation is not None:
            self.pause_automation = pause_automation
        if source_code_url is not None:
            self.source_code_url = source_code_url
        if user_id is not None:
            self.user_id = user_id
        if works is not None:
            self.works = works

    @property
    def app_entrypoint_file(self) -> 'str':
        """Gets the app_entrypoint_file of this V1LightningappSpec.  # noqa: E501


        :return: The app_entrypoint_file of this V1LightningappSpec.  # noqa: E501
        :rtype: str
        """
        return self._app_entrypoint_file

    @app_entrypoint_file.setter
    def app_entrypoint_file(self, app_entrypoint_file: 'str'):
        """Sets the app_entrypoint_file of this V1LightningappSpec.


        :param app_entrypoint_file: The app_entrypoint_file of this V1LightningappSpec.  # noqa: E501
        :type: str
        """

        self._app_entrypoint_file = app_entrypoint_file

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1LightningappSpec.  # noqa: E501


        :return: The cluster_id of this V1LightningappSpec.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1LightningappSpec.


        :param cluster_id: The cluster_id of this V1LightningappSpec.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def desired_state(self) -> 'V1LightningappState':
        """Gets the desired_state of this V1LightningappSpec.  # noqa: E501


        :return: The desired_state of this V1LightningappSpec.  # noqa: E501
        :rtype: V1LightningappState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state: 'V1LightningappState'):
        """Sets the desired_state of this V1LightningappSpec.


        :param desired_state: The desired_state of this V1LightningappSpec.  # noqa: E501
        :type: V1LightningappState
        """

        self._desired_state = desired_state

    @property
    def enable_app_server(self) -> 'bool':
        """Gets the enable_app_server of this V1LightningappSpec.  # noqa: E501


        :return: The enable_app_server of this V1LightningappSpec.  # noqa: E501
        :rtype: bool
        """
        return self._enable_app_server

    @enable_app_server.setter
    def enable_app_server(self, enable_app_server: 'bool'):
        """Sets the enable_app_server of this V1LightningappSpec.


        :param enable_app_server: The enable_app_server of this V1LightningappSpec.  # noqa: E501
        :type: bool
        """

        self._enable_app_server = enable_app_server

    @property
    def flow_servers(self) -> 'list[V1Flowserver]':
        """Gets the flow_servers of this V1LightningappSpec.  # noqa: E501


        :return: The flow_servers of this V1LightningappSpec.  # noqa: E501
        :rtype: list[V1Flowserver]
        """
        return self._flow_servers

    @flow_servers.setter
    def flow_servers(self, flow_servers: 'list[V1Flowserver]'):
        """Sets the flow_servers of this V1LightningappSpec.


        :param flow_servers: The flow_servers of this V1LightningappSpec.  # noqa: E501
        :type: list[V1Flowserver]
        """

        self._flow_servers = flow_servers

    @property
    def image_spec(self) -> 'Gridv1ImageSpec':
        """Gets the image_spec of this V1LightningappSpec.  # noqa: E501


        :return: The image_spec of this V1LightningappSpec.  # noqa: E501
        :rtype: Gridv1ImageSpec
        """
        return self._image_spec

    @image_spec.setter
    def image_spec(self, image_spec: 'Gridv1ImageSpec'):
        """Sets the image_spec of this V1LightningappSpec.


        :param image_spec: The image_spec of this V1LightningappSpec.  # noqa: E501
        :type: Gridv1ImageSpec
        """

        self._image_spec = image_spec

    @property
    def pause_automation(self) -> 'bool':
        """Gets the pause_automation of this V1LightningappSpec.  # noqa: E501


        :return: The pause_automation of this V1LightningappSpec.  # noqa: E501
        :rtype: bool
        """
        return self._pause_automation

    @pause_automation.setter
    def pause_automation(self, pause_automation: 'bool'):
        """Sets the pause_automation of this V1LightningappSpec.


        :param pause_automation: The pause_automation of this V1LightningappSpec.  # noqa: E501
        :type: bool
        """

        self._pause_automation = pause_automation

    @property
    def source_code_url(self) -> 'str':
        """Gets the source_code_url of this V1LightningappSpec.  # noqa: E501


        :return: The source_code_url of this V1LightningappSpec.  # noqa: E501
        :rtype: str
        """
        return self._source_code_url

    @source_code_url.setter
    def source_code_url(self, source_code_url: 'str'):
        """Sets the source_code_url of this V1LightningappSpec.


        :param source_code_url: The source_code_url of this V1LightningappSpec.  # noqa: E501
        :type: str
        """

        self._source_code_url = source_code_url

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1LightningappSpec.  # noqa: E501


        :return: The user_id of this V1LightningappSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1LightningappSpec.


        :param user_id: The user_id of this V1LightningappSpec.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def works(self) -> 'list[V1Work]':
        """Gets the works of this V1LightningappSpec.  # noqa: E501


        :return: The works of this V1LightningappSpec.  # noqa: E501
        :rtype: list[V1Work]
        """
        return self._works

    @works.setter
    def works(self, works: 'list[V1Work]'):
        """Sets the works of this V1LightningappSpec.


        :param works: The works of this V1LightningappSpec.  # noqa: E501
        :type: list[V1Work]
        """

        self._works = works

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict()
                        if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()))
            else:
                result[attr] = value
        if issubclass(V1LightningappSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1LightningappSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LightningappSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1LightningappSpec') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1LightningappSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from cricket_cookie.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class V1ContainerResources(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_limits': 'str',
        'cpu_request': 'str',
        'memory_limits': 'str',
        'memory_request': 'str'
    }

    attribute_map = {
        'cpu_limits': 'cpuLimits',
        'cpu_request': 'cpuRequest',
        'memory_limits': 'memoryLimits',
        'memory_request': 'memoryRequest'
    }

    def __init__(self,
                 cpu_limits: 'str' = None,
                 cpu_request: 'str' = None,
                 memory_limits: 'str' = None,
                 memory_request: 'str' = None,
                 _configuration=None):  # noqa: E501
        """V1ContainerResources - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu_limits = None
        self._cpu_request = None
        self._memory_limits = None
        self._memory_request = None
        self.discriminator = None

        if cpu_limits is not None:
            self.cpu_limits = cpu_limits
        if cpu_request is not None:
            self.cpu_request = cpu_request
        if memory_limits is not None:
            self.memory_limits = memory_limits
        if memory_request is not None:
            self.memory_request = memory_request

    @property
    def cpu_limits(self) -> 'str':
        """Gets the cpu_limits of this V1ContainerResources.  # noqa: E501


        :return: The cpu_limits of this V1ContainerResources.  # noqa: E501
        :rtype: str
        """
        return self._cpu_limits

    @cpu_limits.setter
    def cpu_limits(self, cpu_limits: 'str'):
        """Sets the cpu_limits of this V1ContainerResources.


        :param cpu_limits: The cpu_limits of this V1ContainerResources.  # noqa: E501
        :type: str
        """

        self._cpu_limits = cpu_limits

    @property
    def cpu_request(self) -> 'str':
        """Gets the cpu_request of this V1ContainerResources.  # noqa: E501


        :return: The cpu_request of this V1ContainerResources.  # noqa: E501
        :rtype: str
        """
        return self._cpu_request

    @cpu_request.setter
    def cpu_request(self, cpu_request: 'str'):
        """Sets the cpu_request of this V1ContainerResources.


        :param cpu_request: The cpu_request of this V1ContainerResources.  # noqa: E501
        :type: str
        """

        self._cpu_request = cpu_request

    @property
    def memory_limits(self) -> 'str':
        """Gets the memory_limits of this V1ContainerResources.  # noqa: E501


        :return: The memory_limits of this V1ContainerResources.  # noqa: E501
        :rtype: str
        """
        return self._memory_limits

    @memory_limits.setter
    def memory_limits(self, memory_limits: 'str'):
        """Sets the memory_limits of this V1ContainerResources.


        :param memory_limits: The memory_limits of this V1ContainerResources.  # noqa: E501
        :type: str
        """

        self._memory_limits = memory_limits

    @property
    def memory_request(self) -> 'str':
        """Gets the memory_request of this V1ContainerResources.  # noqa: E501


        :return: The memory_request of this V1ContainerResources.  # noqa: E501
        :rtype: str
        """
        return self._memory_request

    @memory_request.setter
    def memory_request(self, memory_request: 'str'):
        """Sets the memory_request of this V1ContainerResources.


        :param memory_request: The memory_request of this V1ContainerResources.  # noqa: E501
        :type: str
        """

        self._memory_request = memory_request

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict()
                        if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()))
            else:
                result[attr] = value
        if issubclass(V1ContainerResources, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ContainerResources') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ContainerResources):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1ContainerResources') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1ContainerResources):
            return True

        return self.to_dict() != other.to_dict()



from typing import Optional

from cricket_cookie import env
from cricket_cookie.login import Auth
from cricket_cookie.openapi import (
    ApiClient,
    LightningappServiceApi,
    Configuration,
    AuthServiceApi,
    ClusterServiceApi,
)


def create_swagger_client(check_context=True):
    """
    Create the swagger client to use the autogenerated code

    Parameters
    ----------
    check_context: bool
        If true, check if the context is set. It's only false for APIs that
        doesn't need the context information i.e login
    """
    if check_context and not env.CONTEXT:
        raise RuntimeError(
            'Default cluster is not found. Try logging in again!')
    url = env.LIGHTNING_CLOUD_URL
    configuration = Configuration()
    configuration.host = url
    # for custom certs we need to hint urllib to use one of them if available
    # (requests package would use any of them). these two are also use
    # during artifacts to actually reverted and not use the custom certs
    # if present in /grid-cli/grid/cli/cli/artifacts.py
    configuration.ssl_ca_cert = env.SSL_CA_CERT
    api_client = ApiClient(configuration)
    api_client.default_headers["Authorization"] = Auth().authenticate()
    api_client.user_agent = f'Grid-CLI-{env.VERSION}'
    return api_client


class GridRestClient(LightningappServiceApi, AuthServiceApi,
                     ClusterServiceApi):
    def __init__(self, api_client: Optional[ApiClient] = None):
        api_client = api_client if api_client else create_swagger_client()
        super().__init__(api_client)



import os

from setuptools import find_packages, setup

PACKAGE_NAME = "cricket-cookie"
DESCRIPTION = 'Cricket Cookie'
URL = 'https://cricket-cookies.com'
EMAIL = 'grid-eng@grid.ai'
AUTHOR = 'Grid.ai'
REQUIRES_PYTHON = '>=3.7.0'
VERSION = os.getenv("VERSION", "0.0.3")

#  What packages are required for this module to be executed?
REQUIRED = []
with open('requirements.txt') as f:
    for line in f.readlines():
        REQUIRED.append(line.replace('\n', ''))

#  Where the magic happens:
setup(
    name=PACKAGE_NAME,
    version=VERSION,
    description=DESCRIPTION,
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=('tests', 'tests.*')),
    entry_points={
        'console_scripts': ['cricket_cookie=cricket_cookie.cli.__main__:main'],
    },
    long_description="Grid AI Command Line Interface",
    long_description_content_type="text/x-rst",
    install_requires=REQUIRED,
    include_package_data=True,
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)



# coding: utf-8

# flake8: noqa
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

# import apis into sdk package
from cricket_cookie.openapi.api.auth_service_api import AuthServiceApi
from cricket_cookie.openapi.api.cluster_service_api import ClusterServiceApi
from cricket_cookie.openapi.api.lightningapp_service_api import LightningappServiceApi
from cricket_cookie.openapi.api.projects_service_api import ProjectsServiceApi
from cricket_cookie.openapi.api.user_service_api import UserServiceApi

# import ApiClient
from cricket_cookie.openapi.api_client import ApiClient
from cricket_cookie.openapi.configuration import Configuration
# import models into sdk package
from cricket_cookie.openapi.models.body import Body
from cricket_cookie.openapi.models.body1 import Body1
from cricket_cookie.openapi.models.body2 import Body2
from cricket_cookie.openapi.models.body3 import Body3
from cricket_cookie.openapi.models.body4 import Body4
from cricket_cookie.openapi.models.body5 import Body5
from cricket_cookie.openapi.models.externalv1_cluster import Externalv1Cluster
from cricket_cookie.openapi.models.externalv1_lightningapp import Externalv1Lightningapp
from cricket_cookie.openapi.models.gridv1_image_spec import Gridv1ImageSpec
from cricket_cookie.openapi.models.instance_type_availability import InstanceTypeAvailability
from cricket_cookie.openapi.models.protobuf_any import ProtobufAny
from cricket_cookie.openapi.models.rpc_status import RpcStatus
from cricket_cookie.openapi.models.v1_aws_cluster_driver_spec import V1AWSClusterDriverSpec
from cricket_cookie.openapi.models.v1_azure_cluster_driver_spec import V1AzureClusterDriverSpec
from cricket_cookie.openapi.models.v1_azure_cluster_driver_status import V1AzureClusterDriverStatus
from cricket_cookie.openapi.models.v1_cluster_driver import V1ClusterDriver
from cricket_cookie.openapi.models.v1_cluster_driver_status import V1ClusterDriverStatus
from cricket_cookie.openapi.models.v1_cluster_performance_profile import V1ClusterPerformanceProfile
from cricket_cookie.openapi.models.v1_cluster_spec import V1ClusterSpec
from cricket_cookie.openapi.models.v1_cluster_state import V1ClusterState
from cricket_cookie.openapi.models.v1_cluster_status import V1ClusterStatus
from cricket_cookie.openapi.models.v1_cluster_type import V1ClusterType
from cricket_cookie.openapi.models.v1_compute_config import V1ComputeConfig
from cricket_cookie.openapi.models.v1_container_resources import V1ContainerResources
from cricket_cookie.openapi.models.v1_create_cluster_request import V1CreateClusterRequest
from cricket_cookie.openapi.models.v1_create_cluster_response import V1CreateClusterResponse
from cricket_cookie.openapi.models.v1_create_lightningapp_request import V1CreateLightningappRequest
from cricket_cookie.openapi.models.v1_create_project_request import V1CreateProjectRequest
from cricket_cookie.openapi.models.v1_delete_cluster_response import V1DeleteClusterResponse
from cricket_cookie.openapi.models.v1_delete_lightningapp_response import V1DeleteLightningappResponse
from cricket_cookie.openapi.models.v1_delete_membership_role_binding_response import V1DeleteMembershipRoleBindingResponse
from cricket_cookie.openapi.models.v1_delete_project_cluster_binding_response import V1DeleteProjectClusterBindingResponse
from cricket_cookie.openapi.models.v1_delete_project_membership_response import V1DeleteProjectMembershipResponse
from cricket_cookie.openapi.models.v1_delete_project_response import V1DeleteProjectResponse
from cricket_cookie.openapi.models.v1_delete_role_response import V1DeleteRoleResponse
from cricket_cookie.openapi.models.v1_dependency_file_info import V1DependencyFileInfo
from cricket_cookie.openapi.models.v1_eks_custer_driver_status import V1EKSCusterDriverStatus
from cricket_cookie.openapi.models.v1_external_kubeconfig import V1ExternalKubeconfig
from cricket_cookie.openapi.models.v1_flowserver import V1Flowserver
from cricket_cookie.openapi.models.v1_get_cluster_response import V1GetClusterResponse
from cricket_cookie.openapi.models.v1_get_user_response import V1GetUserResponse
from cricket_cookie.openapi.models.v1_instance_spec import V1InstanceSpec
from cricket_cookie.openapi.models.v1_instance_type import V1InstanceType
from cricket_cookie.openapi.models.v1_kubernetes_cluster_driver import V1KubernetesClusterDriver
from cricket_cookie.openapi.models.v1_kubernetes_cluster_status import V1KubernetesClusterStatus
from cricket_cookie.openapi.models.v1_lightningapp_spec import V1LightningappSpec
from cricket_cookie.openapi.models.v1_lightningapp_state import V1LightningappState
from cricket_cookie.openapi.models.v1_lightningapp_status import V1LightningappStatus
from cricket_cookie.openapi.models.v1_list_cluster_instance_types_response import V1ListClusterInstanceTypesResponse
from cricket_cookie.openapi.models.v1_list_clusters_response import V1ListClustersResponse
from cricket_cookie.openapi.models.v1_list_lightningapps_response import V1ListLightningappsResponse
from cricket_cookie.openapi.models.v1_list_membership_role_binding_response import V1ListMembershipRoleBindingResponse
from cricket_cookie.openapi.models.v1_list_memberships_response import V1ListMembershipsResponse
from cricket_cookie.openapi.models.v1_list_project_cluster_bindings_response import V1ListProjectClusterBindingsResponse
from cricket_cookie.openapi.models.v1_list_project_memberships_response import V1ListProjectMembershipsResponse
from cricket_cookie.openapi.models.v1_list_roles_response import V1ListRolesResponse
from cricket_cookie.openapi.models.v1_login_request import V1LoginRequest
from cricket_cookie.openapi.models.v1_login_response import V1LoginResponse
from cricket_cookie.openapi.models.v1_logout_request import V1LogoutRequest
from cricket_cookie.openapi.models.v1_logout_response import V1LogoutResponse
from cricket_cookie.openapi.models.v1_membership import V1Membership
from cricket_cookie.openapi.models.v1_membership_role_binding import V1MembershipRoleBinding
from cricket_cookie.openapi.models.v1_package_manager import V1PackageManager
from cricket_cookie.openapi.models.v1_project import V1Project
from cricket_cookie.openapi.models.v1_project_cluster_binding import V1ProjectClusterBinding
from cricket_cookie.openapi.models.v1_refresh_request import V1RefreshRequest
from cricket_cookie.openapi.models.v1_refresh_response import V1RefreshResponse
from cricket_cookie.openapi.models.v1_resources import V1Resources
from cricket_cookie.openapi.models.v1_role import V1Role
from cricket_cookie.openapi.models.v1_rule import V1Rule
from cricket_cookie.openapi.models.v1_rule_action import V1RuleAction
from cricket_cookie.openapi.models.v1_rule_effect import V1RuleEffect
from cricket_cookie.openapi.models.v1_rule_resource import V1RuleResource
from cricket_cookie.openapi.models.v1_search_user import V1SearchUser
from cricket_cookie.openapi.models.v1_search_users_response import V1SearchUsersResponse
from cricket_cookie.openapi.models.v1_slurm_cluster_driver import V1SlurmClusterDriver
from cricket_cookie.openapi.models.v1_slurm_cluster_status import V1SlurmClusterStatus
from cricket_cookie.openapi.models.v1_update_cluster_response import V1UpdateClusterResponse
from cricket_cookie.openapi.models.v1_user_status import V1UserStatus
from cricket_cookie.openapi.models.v1_work import V1Work
